@@ -17,8 +17,8 @@
     02110-1301, USA.
 */
 
-#ifndef KMANAGESIEVE_SESSIONTHREAD_H
-#define KMANAGESIEVE_SESSIONTHREAD_H
+#ifndef KMANAGESIEVE_SESSIONTHREAD_P_H
+#define KMANAGESIEVE_SESSIONTHREAD_P_H
 
 #include <QObject>
 #include <QUrl>
@@ -52,9 +52,11 @@ public:
 
     void startSsl();
 
+    enum { AuthenticationError = 1500 }; // "extend" KTcpSocket::Error
+
 Q_SIGNALS:
     void responseReceived(const KManageSieve::Response &response, const QByteArray &data);
-    void error(const QString &error);
+    void error(int errorCode, const QString &error);
     void authenticationDone();
     void sslDone();
     void sslError(const KSslErrorUiData &data);
@@ -81,8 +83,10 @@ private:
     bool saslInteract(void *in);
     bool saslClientStep(const QByteArray &challenge);
     void sslResult(bool encrypted);
+    void handleSaslAuthError();
 
 private:
+    Q_DISABLE_COPY(SessionThread)
     Session *m_session = nullptr;
     KTcpSocket *m_socket = nullptr;
 
@@ -99,4 +103,4 @@ private:
 };
 } // namespace KManageSieve
 
-#endif // KMANAGESIEVE_SESSIONTHREAD_H
+#endif // KMANAGESIEVE_SESSIONTHREAD_P_H
